import express, { Request, Response } from "express";
import { Counter, collectDefaultMetrics, register } from "prom-client";

const router = express.Router();


// Collect default system metrics (e.g., CPU, memory usage)
const prefix = 'locationhub_';
collectDefaultMetrics({ prefix });

// Define a custom Counter metric
const requestCounter = new Counter({
  name: "http_requests_total",
  help: "Total number of HTTP requests",
  labelNames: ["method", "route", "status"], // Labels for filtering in Prometheus
});

// Define the metrics endpoint
router.get("/", async (req: Request, res: Response) => {
  try {
    console.log("Metric Endpoint triggered");

    // Increment the counter with labels
    requestCounter.inc({ method: req.method, route: req.route.path, status: 200 });

    // Expose metrics in Prometheus format
    res.set("Content-Type", register.contentType);
    res.send(await register.metrics());
  } catch (error) {
    // Increment the counter for errors
    requestCounter.inc({ method: req.method, route: req.route.path, status: 500 });

    console.error("Error running metrics endpoint:", error);
    res.status(500).json({ error: "Error running metrics endpoint" });
  }
});

export default router;
